##  Implied and Custom Impacts of Transformations
When Transformations are detailed in the Initiative Fact Sheet, the process of deconstructing the Transformation results in the creation of several implied impacts. Additionally, you can also define custom impacts. Typically, during the planning of transformations, not every detail is initially determined. However, starting with a defined scope, you can refine and fine-tune details as uncertainties decrease over time. At this juncture, you have the opportunity to specify custom impacts.
The following implied and custom impacts are available:
  * Set lifecycle phase: Sets a life cycle field of a Fact Sheet (e.g., An Application is set to active when the Transformation is executed).
  * Set / Copy field to: Sets or copy a field on a particular Fact Sheet to another Fact Sheet(e.g., A Business Capability will change its maturity when the Transformation is executed).
  * Set relation validity: The validity refers to the active from/until fields on the relations of every Fact Sheet. When using this impact, you don't need to create the relation first, as the impact does it by default.
  * Set relation field to: Set any relation field of Fact Sheet. When using this impact, you don't need to create the relation first, as the impact does it by default.
  * Create / Remove relations: Creates or removes relations of one type (Organization, children, etc.) from one source Fact Sheet to a target Fact Sheet.
  * Create / Remove relation constraints: Create or remove constraining relations of one type (Organization, Business Capability, etc) from one source Fact Sheet to a target Fact Sheet.
  * Copy / Move all relations from: Copies or moves all relations of one type (Organization, children, etc.) from one source Fact Sheet to a target Fact Sheet.
  * Remove all relations: Remove all relations of one type (Organization, children, etc.) from a Fact Sheet type.
  * Replace/ Add / Remove tags: Adds or removes a tag or replaces all tags of the selected Fact Sheet.


**Note**
Starting December 2025, new workspaces no longer support creating or removing relations as custom impacts.
This affects:
  * Creating or adding relations as custom impacts in the Transformations tab of fact sheets
  * Creating or adding relations as custom impacts in custom transformation templates in the administration area
